==> seedsui-react-5.5.1.tgz: package/es/DatePicker/RangeModal/Utils.js <==
import Bridge from './../../Bridge';
import locale from './../../locale';
export default {
  getDateRange: function getDateRange(type) {
    var date = null; // 今天

    if (type === 'today') {
      date = new Date();
      return {
        startDate: date.format('YYYY-MM-DD'),
        endDate: date.format('YYYY-MM-DD')
      };
    } // 昨天


    if (type === 'yesterday') {
      date = new Date();
      date.prevDate();
      return {
        startDate: date.format('YYYY-MM-DD'),
        endDate: date.format('YYYY-MM-DD')
      };
    } // 本月


    if (type === 'month') {
      date = new Date();
      date.firstMonthDate();
      return {
        startDate: date.format('YYYY-MM-DD'),
        endDate: new Date().format('YYYY-MM-DD')
      };
    } // 上月


    if (type === 'prevmonth') {
      var sDate = new Date();
      sDate.prevMonth();
      sDate.firstMonthDate();
      var eDate = new Date();
      eDate.prevMonth();
      eDate.lastMonthDate();
      return {
        startDate: sDate.format('YYYY-MM-DD'),
        endDate: eDate.format('YYYY-MM-DD')
      };
    } // 最近7内


    if (type === '7') {
      date = new Date();
      date.prevDate(7);
      return {
        startDate: date.format('YYYY-MM-DD'),
        endDate: new Date().format('YYYY-MM-DD')
      };
    } // 最近30天


    if (type === '30') {
      date = new Date();
      date.prevDate(30);
      return {
        startDate: date.format('YYYY-MM-DD'),
        endDate: new Date().format('YYYY-MM-DD')
      };
    }
  },
  getDateName: function getDateName(startDate, endDate) {
    var date = null; // 今天

    date = this.getDateRange('today');

    if (endDate === date.endDate && startDate === date.startDate) {
      return locale('今天', 'datepopover_today');
    } // 昨天


    date = this.getDateRange('yesterday');

    if (endDate === date.endDate && startDate === date.startDate) {
      return locale('昨天', 'datepopover_yesterday');
    } // 本月


    date = this.getDateRange('month');

    if (endDate === date.endDate && startDate === date.startDate) {
      return locale('本月', 'datepopover_this_month');
    } // 上月


    date = this.getDateRange('prevmonth');

    if (endDate === date.endDate && startDate === date.startDate) {
      return locale('上月', 'datepopover_last_month');
    } // 最近7内


    date = this.getDateRange('7');

    if (endDate === date.endDate && startDate === date.startDate) {
      return locale(locale('最近7天', 'datepopover_last_days', ['7']));
    } // 最近30天


    date = this.getDateRange('30');

    if (endDate === date.endDate && startDate === date.startDate) {
      return locale('最近30天', 'datepopover_last_days', ['30']);
    } // 其它


    return '';
  },
  // 计算区间, 区间内
  validateRange: function validateRange(value, config) {
    var range = config.range;
    var onError = config.onError;
    if (!range) return true;
    if (!Array.isArray(value) || value.length !== 2) return true;
    var startDate = value[0] instanceof Date ? value[0] : null;
    var endDate = value[1] instanceof Date ? value[1] : null;

    if (startDate && endDate) {
      var diff = startDate.diff(endDate);

      if (diff.days > range) {
        var errMsg = locale("\u81EA\u5B9A\u4E49\u65F6\u95F4\u533A\u95F4\u4E0D\u80FD\u8D85\u8FC7" + range + "\u5929", 'hint_error_datepopover_custom_date_range_timeout', [range]);

        if (onError) {
          onError({
            errMsg: errMsg,
            range: range,
            value: value
          });
        } else {
          Bridge.showToast(errMsg, {
            mask: false
          });
        }

        return false;
      }
    }

    return true;
  }
};

==> seedsui-react-5.5.3.tgz: package/es/DatePicker/RangeModal/Utils.js <==
import Bridge from './../../Bridge';
import locale from './../../locale';
export default {
  getDateRange: function getDateRange(type) {
    var date = null; // 今天

    if (type === 'today') {
      date = new Date();
      return {
        startDate: date.format('YYYY-MM-DD'),
        endDate: date.format('YYYY-MM-DD')
      };
    } // 昨天


    if (type === 'yesterday') {
      date = new Date();
      date.prevDate();
      return {
        startDate: date.format('YYYY-MM-DD'),
        endDate: date.format('YYYY-MM-DD')
      };
    } // 本月


    if (type === 'month') {
      date = new Date();
      date.firstMonthDate();
      return {
        startDate: date.format('YYYY-MM-DD'),
        endDate: new Date().format('YYYY-MM-DD')
      };
    } // 上月


    if (type === 'prevmonth') {
      var sDate = new Date();
      sDate.prevMonth();
      sDate.firstMonthDate();
      var eDate = new Date();
      eDate.prevMonth();
      eDate.lastMonthDate();
      return {
        startDate: sDate.format('YYYY-MM-DD'),
        endDate: eDate.format('YYYY-MM-DD')
      };
    } // 最近7内


    if (type === '7') {
      date = new Date();
      date.prevDate(7);
      return {
        startDate: date.format('YYYY-MM-DD'),
        endDate: new Date().format('YYYY-MM-DD')
      };
    } // 最近30天


    if (type === '30') {
      date = new Date();
      date.prevDate(30);
      return {
        startDate: date.format('YYYY-MM-DD'),
        endDate: new Date().format('YYYY-MM-DD')
      };
    }
  },
  getDateName: function getDateName(startDate, endDate) {
    var date = null; // 今天

    date = this.getDateRange('today');

    if (endDate === date.endDate && startDate === date.startDate) {
      return locale('今天', 'datepopover_today');
    } // 昨天


    date = this.getDateRange('yesterday');

    if (endDate === date.endDate && startDate === date.startDate) {
      return locale('昨天', 'datepopover_yesterday');
    } // 本月


    date = this.getDateRange('month');

    if (endDate === date.endDate && startDate === date.startDate) {
      return locale('本月', 'datepopover_this_month');
    } // 上月


    date = this.getDateRange('prevmonth');

    if (endDate === date.endDate && startDate === date.startDate) {
      return locale('上月', 'datepopover_last_month');
    } // 最近7内


    date = this.getDateRange('7');

    if (endDate === date.endDate && startDate === date.startDate) {
      return locale(locale('最近7天', 'datepopover_last_days', ['7']));
    } // 最近30天


    date = this.getDateRange('30');

    if (endDate === date.endDate && startDate === date.startDate) {
      return locale('最近30天', 'datepopover_last_days', ['30']);
    } // 其它


    return '';
  },
  // 计算区间, 区间内
  validateRange: function validateRange(value, config) {
    var daysLimit = config.daysLimit;
    var onError = config.onError;
    if (!daysLimit) return true;
    if (!Array.isArray(value) || value.length !== 2) return true;
    var startDate = value[0] instanceof Date ? value[0] : null;
    var endDate = value[1] instanceof Date ? value[1] : null;

    if (startDate && endDate) {
      var diff = startDate.diff(endDate);

      if (diff.days > daysLimit) {
        var errMsg = locale("\u81EA\u5B9A\u4E49\u65F6\u95F4\u533A\u95F4\u4E0D\u80FD\u8D85\u8FC7" + daysLimit + "\u5929", 'hint_error_datepopover_custom_date_range_timeout', [daysLimit]);

        if (onError) {
          onError({
            errMsg: errMsg,
            daysLimit: daysLimit,
            value: value
          });
        } else {
          Bridge.showToast(errMsg, {
            mask: false
          });
        }

        return false;
      }
    }

    return true;
  }
};
